@@ -1,7 +1,7 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
 # Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta,
-#			Bettina Gruen and Kurt Hornik
+# 			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,11 +32,11 @@
 #' @family interest measures
 #' @family postprocessing
 #' @family associations functions
-#' 
+#'
 #' @param x a set of [rules].
 #' @param transactions optional set of [transactions]. Only needed if not sufficient
 #'    interest measures are available in `x`. If the test should be performed
-#'    on a transaction set different then the one used for mining (use `reuse = FALSE`). 
+#'    on a transaction set different then the one used for mining (use `reuse = FALSE`).
 #' @param method test to use. Options are `"fisher"`, `"chisq"`. Note that
 #' the contingency table is likely to have cells with low expected values and
 #' that thus Fisher's Exact Test might be more appropriate than the chi-squared
@@ -45,8 +45,8 @@
 #' @param adjust method to adjust for multiple comparisons. Some options are
 #' `"none"`, `"bonferroni"`, `"holm"`, `"fdr"`, etc. (see
 #' [stats::p.adjust()] for more methods)
-#' @param reuse logical indicating if information in the quality slot should be 
-#'   reuse for calculating the measures. 
+#' @param reuse logical indicating if information in the quality slot should be
+#'   reuse for calculating the measures.
 #' @param ... further arguments are passed on to [interestMeasure()].
 #' @return returns a logical vector indicating which rules are significant.
 #' @author Michael Hahsler
@@ -65,35 +65,43 @@
 #'
 #' # Adjust P-values for multiple comparisons
 #' rules[is.significant(rules, adjust = "bonferroni")]
-setGeneric("is.significant",
-  function(x, ...)
-    standardGeneric("is.significant"))
+setGeneric(
+  "is.significant",
+  function(x, ...) {
+    standardGeneric("is.significant")
+  }
+)
 
 #' @rdname is.significant
-setMethod("is.significant", signature(x = "rules"),
-  function(x,
-    transactions = NULL,
-    method = "fisher",
-    alpha = 0.01,
-    adjust = "none",
-    reuse = TRUE,
-    ...) {
+setMethod(
+  "is.significant", signature(x = "rules"),
+  function(
+      x,
+      transactions = NULL,
+      method = "fisher",
+      alpha = 0.01,
+      adjust = "none",
+      reuse = TRUE,
+      ...) {
     methods <- c("fisher", "chisq")
     m <- pmatch(tolower(method), methods)
-    if (is.na(m))
-      stop("Unknown method. Available methods are: ", 
-           paste(sQuote(methods), collapse = ", "))
+    if (is.na(m)) {
+      stop(
+        "Unknown method. Available methods are: ",
+        paste(sQuote(methods), collapse = ", ")
+      )
+    }
     method <- methods[m]
-    
-    if (method == "fisher")
+
+    if (method == "fisher") {
       p <- interestMeasure(x,
         measure = "fishersExactTest",
         transactions = transactions,
         reuse = reuse,
-        ...)
-    
-    ### chisq
-    else
+        ...
+      )
+    } ### chisq
+    else {
       p <- interestMeasure(
         x,
         measure = "chiSquared",
@@ -102,7 +110,9 @@ setMethod("is.significant", signature(x = "rules"),
         reuse = reuse,
         ...
       )
-    
+    }
+
     p <- stats::p.adjust(p, method = adjust)
     p <= alpha
-  })
+  }
+)
