@@ -2,6 +2,7 @@
 #include <Rinternals.h>
 #include <Rdefines.h>
 #include "newS4object.h"
+#include "r_memcpy.h"
 
 // Compute auto- or cross-similarities over the columns
 // of ngCMatrix objects, using optional element weights.
@@ -94,11 +95,11 @@ SEXP R_similarity_ngCMatrix(SEXP x, SEXP y, SEXP R_method, SEXP R_weight) {
       
       PROTECT(t = ir);
       setAttrib(r, install("i"), PROTECT(ir = allocVector(INTSXP, LENGTH(ir) * 2)));
-      memcpy(INTEGER(ir), INTEGER(t), sizeof(int) * n);
+      r_memcpy(INTEGER(ir), INTEGER(t), sizeof(int) * n);
       
       PROTECT(t = xr);
       setAttrib(r, install("x"), PROTECT(xr = allocVector(REALSXP, LENGTH(ir))));
-      memcpy(REAL(xr), REAL(t), sizeof(double) * n);
+      r_memcpy(REAL(xr), REAL(t), sizeof(double) * n);
       UNPROTECT(4);
     }
     
@@ -179,11 +180,11 @@ SEXP R_similarity_ngCMatrix(SEXP x, SEXP y, SEXP R_method, SEXP R_weight) {
     
     PROTECT(ix = ir);
     setAttrib(r, install("i"), PROTECT(ir = allocVector(INTSXP, n)));
-    memcpy(INTEGER(ir), INTEGER(ix), sizeof(int) * n);
+    r_memcpy(INTEGER(ir), INTEGER(ix), sizeof(int) * n);
     
     PROTECT(ix = xr);
     setAttrib(r, install("x"), PROTECT(xr = allocVector(REALSXP, n)));
-    memcpy(REAL(xr), REAL(ix), sizeof(double) * n);
+    r_memcpy(REAL(xr), REAL(ix), sizeof(double) * n);
     
     UNPROTECT(4);
   }
